function [T,DFE] = chimefindinwav(D,SR)
% T = chimefindinwav(D,SR)
%   Look for the "chimes" signifying the starts of utterances in
%   RATS dev0 transmissions; return their times in seconds.
%   D is the waveform at sampling rate SR.
% 2011-05-18 Dan Ellis dpwe@ee.columbia.edu

targetsr = 8000;
% filter coefficients extracted from actual chime via LPC
%aa = [1.0000   -2.9643    6.8830   -9.8901   11.8273   -9.8324  6.8029   -2.9127    0.9769];

% Break into two filters, to avoid false alarms by requiring
% significant energy in BOTH bands
aa1 = [1.0000   -0.6174    2.0745   -0.6138    0.9881];
aa2 = [1.0000   -2.3469    3.3596   -2.3336    0.9886];

% Flanking bands - similar structure, nearby but different
% frequencies
bb1 = [1.0000   -0.8054    2.1415   -0.8006    0.9881];
bb2 = [1.0000   -2.4995    3.5451   -2.4846    0.9881];

if SR ~= targetsr
  D = resample(D,targetsr,SR);
  SR = targetsr;
end

% extract filter & smooth
swin = hanning(255)';
dsfact = 40;  % 8000/40 = 5 ms resolution

% filter the signal, smooth energy, downsample
DF1 = conv(filter(1,aa1,D).^2, swin);
DF1 = DF1(round(length(swin)/2):dsfact:end);

DF2 = conv(filter(1,aa2,D).^2, swin);
DF2 = DF2(round(length(swin)/2):dsfact:end);

% .. and with "guard bands"
DN1 = conv(filter(1,bb1,D).^2, swin);
DN1 = DN1(round(length(swin)/2):dsfact:end);
DN2 = conv(filter(1,bb2,D).^2, swin);
DN2 = DN2(round(length(swin)/2):dsfact:end);

% to count, a signal has to hit both filters at once
DFE = sqrt(max(0,(min(DF1-DN1,DF2-DN2))));

SR = SR/dsfact;

% find leading edges
% minimum threshold of 5.0 differentiates files with no chimes at all
% median filtering removes sensitivity to very short spikes in DFE
DFEM = DFE > 0.9*max(5,max(medfilt1(DFE,31)));
% keep these points only if it *stays* high for a while
risingedge = find(DFEM([1, [1:end-1]])==0 & DFEM(1:end)==1);

nhigh = fliplr(conv(fliplr(double(DFEM')),ones(1,32)));
nhigh = nhigh(31+[1:length(DFEM)]);

% so, 20 of the 32 points following this leading edge must be above threshold
risingedge = risingedge(find(nhigh(risingedge)>=20));

T = risingedge/SR - 0.075;
% 0.075 s is the empirical delay between actual chime start and this threshold

%T = DFE;
