%% CHIMEFIND - Tool to realign labels to "chimes" in LDC RATS data
%
% |chimefind| is a Matlab script that uses a custom-designed filter
% to identify the "start-of-utterance" chimes within the "clean" 
% rebroadcast files created by LDC for the RATS program.  It 
% then writes a label file corresponding to the audio file, either 
% based on the found chimes alone, or by taking an existing label 
% file and adjusting the start times to correspond to each chime 
% (while preserving the durations of each segment, and any label 
% contents).  |chimefind| can read both Audacity-format 3-column 
% label files |start end label|, and the 11-column tab-separated 
% omnibus label file distributed as LDC2011E32.

%% Example usage
%
% In the code below, we scan a waveform file and write a new label
% file based on each of the detected chimes.  Since no input labels 
% are provided, the output labels are empty, and the segment end
% times are simply 5 s before the start of the next segment (or end
% of file).  The -disp flag generates an interpretive plot.

chimefind -clean 20110328_070019_0000_lre07ara.clean.flac ...
    -labelsout 20110328_070019_0000_lre07ara.txt -disp 1

%% Usage with label file input
%
% As described abouve, segment durations and labels can be read
% from an external file, either 3 column, or the LDC 11-column
% format.  For the LDC format, we scan for lines tagged with the
% "root" of the wavfile name, and insert the transcript field as
% the label:

chimefind -clean 20110328_070019_0000_lre07ara.clean.flac ...
    -labelsin dev-0-part1-annotation.tsv ...
    -labelsout 20110328_070019_0000_lre07ara.txt ...
    -ldclabels 1 -disp 1 -strict 0

%% Optional arguments
%
% This is the full range of arguments accepted:
%
%   -clean <filename>     Path to clean (ref) wavfile
%   -labelsin <filename>  Input label file name
%   -labelsout <filename> Where to write 3-column output
%   -ldclabels 0/1        Input label file is 3 col <stt end lab> or 11 col
%   -segmap 0/1           Flag to both read and write 4-col segmap files
%   -chimeoffs <time>     Offset time added to chime (default 0.525 s)
%   -strict 0/1           Writes nothing if wrong number of chimes found (1)
%   -disp 0/1             Optional graphic display
%   -dechimeout <filename>  Replace detected chimes with dither & write out

%% Compiled target usage
%
% Invoking the compiled target has the same syntax as above, e.g.
% 
%  ./run_chimefind_prj.sh -clean 20110328_070019_0000_lre07ara.clean.flac -labelsout 20110328_070019_0000_lre07ara.txt

%% Installation
% 
% This package has been compiled for several targets 
% using the Matlab compiler.  You will also need 
% to download and install the Matlab Compiler Runtime (MCR) Installer. 
% Please see the table below:
%
% <html>
% <table border=1>
% <tr><th>Architecture</th><th>Compiled package</th><th>MCR Installer</th></tr>
% <tr><td>32 bit Linux</td>
% <td><a href="chimefind_GLNX86.zip">chimefind_GLNX86.zip</a></td>
% <td><a href="http://www.ee.columbia.edu/~dpwe/tmp/MCRInstaller.bin">Linux MCR Installer</a></td>
% </tr>
% <tr><td>64 bit Linux</td>
% <td><a href="chimefind_GLNXA64.zip">chimefind_GLNXA64.zip</a></td>
% <td><a href="http://www.ee.columbia.edu/~dpwe/tmp/MCRInstaller_glnxa64.bin">Linux 64 bit MCR Installer</a></td></tr>
% <tr><td>64 bit MacOS</td>
% <td><a href="chimefind_MACI64.zip">chimefind_MACI64.zip</a></td>
% <td><a href="http://www.ee.columbia.edu/~dpwe/tmp/MCRInstaller.dmg">MACI64 MCR Installer</a></td></tr>
% </table></html>
% 
% The original Matlab code used to build this compiled target is 
% available at
% 
%   <http://labrosa.ee.columbia.edu/projects/chimefind/>
%
% All sources are in the package <chimefind.zip>.
%
% Feel free to contact me with any problems.
%

%% Changelog
%
% 2011-05-19 v0.1 Initial release
%
% 2011-05-31 v0.2 Added support for "segmap" file input and output
%
% 2011-06-06 v0.3 Fixed false alarms for speech that happened to
% hit one of the frequencies by taking the MIN of two different
% filters, each selecting one of the tone pairs.
%
% 2011-06-06 v0.4 Even more caution in chimefindinwav to avoid 
% spurious matches from noise, and also to impose a minimum energy
% threshold on matches (to avoid finding chimes in chimeless
% files).  Also added -strict flag to suppress writing anything if
% label file is inconsistent.
%
% 2011-06-07 v0.5 STRICT mode now simply assumes that labels
% correspond to chimes in the order that they are presented, and 
% rewrites them regardless (as long as they are within
% matchthresh) instead of trying to find the closest one.  Useful 
% for corrupted segmap files.
%
% 2011-06-10 v0.6 Slightly looser criteria will detect shorter
% chimes; unmatched labels are now reported; added -dechimeout
% option. 
%
% 2011-08-04 v0.7 Added version number to output reports.

%% Acknowledgment
%
% This work was supported by DARPA under the RATS program via a 
% subcontract from the SRI-led team SCENIC.  My work was on behalf 
% of ICSI.
%
% $Header: /Users/dpwe/docs/grants/2010-01-DARPA-RATS/code/chimefind/RCS/demo_chimefind.m,v 1.2 2011/05/03 20:32:37 dpwe Exp dpwe $
